/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.jdbc.mediatypes.builtin;

import org.wso2.registry.RegistryConstants;
import org.wso2.registry.RegistryException;
import org.wso2.registry.Resource;
import org.wso2.registry.jdbc.mediatypes.MediaTypeHandler;
import org.wso2.registry.jdbc.mediatypes.MediaTypeManager;
import org.wso2.usermanager.Realm;

import javax.sql.DataSource;

public class Axis2RepositoryMediaTypeHandler extends MediaTypeHandler {

    public Axis2RepositoryMediaTypeHandler(DataSource dataSource,
                                           Realm realm,
                                           MediaTypeManager mediaTypeManager) {

        super(dataSource, realm, mediaTypeManager);
    }

    public Resource get(String path, Resource rawArtifact) throws RegistryException {
        return null;
    }

    public boolean put(String path, Resource resource) throws RegistryException {

        MediaTypeHandler defaultMediaTypeHandler = mediaTypeManager.getDefaultMediaTypeHandler();
        defaultMediaTypeHandler.put(path, resource);

        String confPath = path +
                          RegistryConstants.PATH_SEPARATOR + RegistryConstants
                .AXIS2_CONF_COLLECTION_NAME;
        Resource confCollection = new Resource();
        confCollection.setDirectory(true);
        confCollection.setPath(confPath);
        confCollection.setMediaType(RegistryConstants.AXIS2_CONF_COLLECTION_MEDIA_TYPE);
        defaultMediaTypeHandler.put(confPath, confCollection);

        String servicesPath = path +
                              RegistryConstants.PATH_SEPARATOR + RegistryConstants
                .AXIS2_SERVICES_COLLECTION_NAME;
        Resource servicesCollection = new Resource();
        servicesCollection.setDirectory(true);
        servicesCollection.setPath(servicesPath);
        servicesCollection.setMediaType(RegistryConstants.AXIS2_SERVICES_COLLECTION_MEDIA_TYPE);
        defaultMediaTypeHandler.put(servicesPath, servicesCollection);

        String modulesPath = path +
                             RegistryConstants.PATH_SEPARATOR + RegistryConstants
                .AXIS2_MODULES_COLLECTION_NAME;
        Resource modulesCollection = new Resource();
        modulesCollection.setDirectory(true);
        modulesCollection.setPath(modulesPath);
        modulesCollection.setMediaType(RegistryConstants.AXIS2_MODULES_COLLECTION_MEDIA_TYPE);
        defaultMediaTypeHandler.put(modulesPath, modulesCollection);

        return true;
    }

    public String importResource(String path, String sourceURL, Resource metadata)
            throws RegistryException {
        return null;
    }

    public boolean delete(String path) throws RegistryException {
        return false;
    }

    public boolean putChild(String childPath, Resource resource) throws RegistryException {

        String childMediaType = resource.getMediaType();

        return RegistryConstants.AXIS2_CONF_COLLECTION_MEDIA_TYPE.equals(childMediaType) ||
                RegistryConstants.AXIS2_SERVICES_COLLECTION_MEDIA_TYPE.equals(childMediaType) ||
                RegistryConstants.AXIS2_MODULES_COLLECTION_MEDIA_TYPE.equals(childMediaType);

    }

    public boolean importChild(String childPath, String sourceURL) throws RegistryException {
        return true;
    }
}
