/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.jdbc.mediatypes.builtin;

import org.wso2.registry.RegistryConstants;
import org.wso2.registry.RegistryException;
import org.wso2.registry.Resource;
import org.wso2.registry.jdbc.mediatypes.MediaTypeHandler;
import org.wso2.registry.jdbc.mediatypes.MediaTypeManager;
import org.wso2.usermanager.Realm;

import javax.sql.DataSource;

public class SynapseRepositoryMediaTypeHandler extends MediaTypeHandler {

    public SynapseRepositoryMediaTypeHandler(DataSource dataSource,
                                             Realm realm,
                                             MediaTypeManager mediaTypeManager) {
        super(dataSource, realm, mediaTypeManager);
    }

    public Resource get(String path, Resource resource) throws RegistryException {
        return null;
    }

    public boolean put(String path, Resource resource) throws RegistryException {

        MediaTypeHandler defaultMediaTypeHandler = mediaTypeManager.getDefaultMediaTypeHandler();
        defaultMediaTypeHandler.put(path, resource);

        String confPath = path +
                          RegistryConstants.PATH_SEPARATOR + RegistryConstants
                .SYNAPSE_CONF_COLLECTION_NAME;
        Resource confCollection = new Resource();
        confCollection.setDirectory(true);
        confCollection.setPath(confPath);
        confCollection.setMediaType(RegistryConstants.SYNAPSE_CONF_COLLECTION_MEDIA_TYPE);
        defaultMediaTypeHandler.put(confPath, confCollection);

        String seqPath = path + RegistryConstants.PATH_SEPARATOR +
                         RegistryConstants.SYNAPSE_SEQUENCES_COLLECTION_NAME;
        Resource seqCollection = new Resource();
        seqCollection.setDirectory(true);
        seqCollection.setPath(seqPath);
        seqCollection.setMediaType(RegistryConstants.SYNAPSE_SEQUENCE_COLLECTION_MEDIA_TYPE);
        defaultMediaTypeHandler.put(seqPath, seqCollection);

        String epPath = path + RegistryConstants.PATH_SEPARATOR +
                        RegistryConstants.SYNAPSE_ENDPOINT_COLLECTION_NAME;
        Resource epCollection = new Resource();
        epCollection.setDirectory(true);
        epCollection.setPath(epPath);
        epCollection.setMediaType(RegistryConstants.SYNAPSE_ENDPOINT_COLLECTION_MEDIA_TYPE);
        defaultMediaTypeHandler.put(epPath, epCollection);

        String proxyServicesPath = path + RegistryConstants.PATH_SEPARATOR +
                                   RegistryConstants.SYNAPSE_PROXY_SERVICES_COLLECTION_NAME;
        Resource proxyCollection = new Resource();
        proxyCollection.setDirectory(true);
        proxyCollection.setPath(proxyServicesPath);
        proxyCollection
                .setMediaType(RegistryConstants.SYNAPSE_PROXY_SERVICES_COLLECTION_MEDIA_TYPE);
        defaultMediaTypeHandler.put(proxyServicesPath, proxyCollection);

        String tasksPath = path + RegistryConstants.PATH_SEPARATOR +
                           RegistryConstants.SYNAPSE_TASKS_COLLECTION_NAME;
        Resource tasksCollection = new Resource();
        tasksCollection.setDirectory(true);
        tasksCollection.setPath(tasksPath);
        tasksCollection.setMediaType(RegistryConstants.SYNAPSE_TASKS_COLLECTION_MEDIA_TYPE);
        defaultMediaTypeHandler.put(tasksPath, tasksCollection);

        String entriesPath = path + RegistryConstants.PATH_SEPARATOR +
                             RegistryConstants.SYNAPSE_ENTRIES_COLLECTION_NAME;
        Resource entryCollection = new Resource();
        entryCollection.setDirectory(true);
        entryCollection.setPath(entriesPath);
        entryCollection.setMediaType(RegistryConstants.SYNAPSE_ENTRIES_COLLECTION_MEDIA_TYPE);
        defaultMediaTypeHandler.put(entriesPath, entryCollection);

        return true;
    }

    public String importResource(String path, String sourceURL, Resource metadata)
            throws RegistryException {
        return null;
    }

    public boolean delete(String path) throws RegistryException {
        return false;
    }

    public boolean putChild(String childPath, Resource resource) throws RegistryException {

        String childMediaType = resource.getMediaType();

        return RegistryConstants.SYNAPSE_CONF_COLLECTION_MEDIA_TYPE.equals(childMediaType) ||
                RegistryConstants.SYNAPSE_SEQUENCE_COLLECTION_MEDIA_TYPE.equals(childMediaType) ||
                RegistryConstants.SYNAPSE_ENDPOINT_COLLECTION_MEDIA_TYPE.equals(childMediaType) ||
                RegistryConstants.SYNAPSE_PROXY_SERVICES_COLLECTION_MEDIA_TYPE.equals(childMediaType)
                || RegistryConstants.SYNAPSE_TASKS_COLLECTION_MEDIA_TYPE.equals(childMediaType) ||
                RegistryConstants.SYNAPSE_ENTRIES_COLLECTION_MEDIA_TYPE.equals(childMediaType);

    }

    public boolean importChild(String childPath, String sourceURL) throws RegistryException {
        return true;
    }
}
