/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.utils;

import org.wso2.registry.RegistryException;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.Registry;
import org.wso2.registry.jdbc.realm.RegistryRealm;
import org.wso2.registry.web.UIConstants;
import org.wso2.registry.web.ConsoleConstants;
import org.wso2.registry.web.actions.UserDetailsAction;
import org.wso2.registry.secure.SecureRegistry;
import org.wso2.usermanager.Realm;
import org.wso2.usermanager.UserManagerException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletException;
import javax.servlet.ServletContext;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Map;

public class UserUtil {

    public static void signIn(HttpServletRequest request, HttpServletResponse response) throws IOException {

        String userName = request.getParameter("userName");
        String password = request.getParameter("password");

        PrintWriter writer = response.getWriter();

        try {

            if (userName.equals(RegistryConstants.SYSTEM_USER)) {
                String msg = "ERROR: Users are not allowed to log in as the system user.";
                writer.write(msg);
                writer.flush();
                return;
            }

            RegistryRealm realm = (RegistryRealm) request.getSession().getServletContext().
                        getAttribute(RegistryConstants.REGISTRY_REALM);

            if (realm.getAuthenticator().authenticate(userName, password)) {

                ServletContext context =
                        request.getSession().getServletContext();
                Registry jdbcRegistry =
                        (Registry) context.getAttribute(RegistryConstants.REGISTRY);

                SecureRegistry secureRegistry =
                        new SecureRegistry(userName, password, jdbcRegistry, realm);
                request.getSession().setAttribute(ConsoleConstants.USER_REGISTRY, secureRegistry);

                request.getSession().
                        setAttribute(UIConstants.PATH_ATTR, RegistryConstants.ROOT_PATH);

                writer.write("SUCCESS: User authenticated.");
                writer.flush();
                return;

            } else {
                writer.write("ERROR: Could not authenticate user " + userName);
                writer.flush();
                return;

            }

        } catch (Exception e) {
            response.getWriter().write("ERROR: " + e.getMessage());
        }
    }

    public static boolean isAdmin(HttpServletRequest request, String userName) throws RegistryException {

        if (RegistryConstants.ADMIN_USER.equals(userName)) {
            return true;
        }

        SecureRegistry secureRegistry = CommonUtil.getUserRegistry(request);
        Realm userRealm = secureRegistry.getUserRealm();

        String[] roles ;
        try {
            roles = userRealm.getUserStoreReader().getUserRoles(userName);
        } catch (UserManagerException e) {
            String msg = "Could not get the roles of the user: " + userName;
            throw new RegistryException(msg);
        }

        return containsString(RegistryConstants.ADMIN_ROLE, roles);
    }

    private static boolean containsString(String value, String[] sArray) {

        for (int i = 0; i < sArray.length; i++) {
            if (sArray[i].equals(value)) {
                return true;
            }
        }

        return false;
    }

    public static void updateFriendlyName(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {

        try {
            String userName = request.getParameter("userName");
            String friendlyName = request.getParameter("friendlyName");
            Registry registry = CommonUtil.getUserRegistry(request);

            SecureRegistry secureRegistry = (SecureRegistry) registry;
            Realm userRealm = secureRegistry.getUserRealm();

            Map userProperties = userRealm.getUserStoreAdmin().getUserProperties(userName);
            userProperties.put("friendlyName", friendlyName);
            userRealm.getUserStoreAdmin().setUserProperties(userName, userProperties);

            UserDetailsAction userDetailsAction = new UserDetailsAction();
            userDetailsAction.setDisplayUserName(userName);
            userDetailsAction.execute(request);
            request.getSession().setAttribute(UIConstants.USER_BEAN, userDetailsAction);

        } catch (Exception e) {
            request.getSession().setAttribute(UIConstants.ERROR_MESSAGE, e.getMessage());
        }

        request.getRequestDispatcher(UIConstants.AJAX_USER_FRIENDLY_NAME_JSP).forward(request,response);
    }
    public static void updatePassword(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        try{
            String userName = request.getParameter("userName");
            String newPassword = request.getParameter("newPassword");
            
            Registry registry = CommonUtil.getUserRegistry(request);

            SecureRegistry secureRegistry = (SecureRegistry) registry;
            Realm userRealm = secureRegistry.getUserRealm();
            userRealm.getUserStoreAdmin().updateUser(userName,newPassword);
            
            //Map userProperties = userRealm.getUserStoreAdmin().getUserProperties(userName);
            //userProperties.put("friendlyName", friendlyName);
            //userRealm.getUserStoreAdmin().setUserProperties(userName, userProperties);

            UserDetailsAction userDetailsAction = new UserDetailsAction();
            userDetailsAction.setDisplayUserName(userName);
            userDetailsAction.execute(request);
            request.getSession().setAttribute(UIConstants.USER_BEAN, userDetailsAction);

        } catch (Exception e) {

        }
        request.getRequestDispatcher(UIConstants.AJAX_USER_PASSWORD_JSP).forward(request,response);
    }

}
